@@ -3,16 +3,40 @@
 
 import base
 import datetime
-#import pytz
+import os
+
+base.utils.DeferImport('pytz')
+
+
+### Length Limits
+
+# Maximum character count in a slug-like string.
+# For import order this is defined in another file, for sake of easy finding it we copy it here.
+MAX_LENGTH_SLUG         = base.utils.strings.MAX_LENGTH_SLUG  # probably 64
+
 
 
 ### Timezones
 
-TIME_UTC                = None          # XYZZY: pytz.utc
-TIME_ZONE               = None          # Filled in during Boot(), after settings are processed.
+def _TryToGetLocalTimeZone():
+  ''' On unix-like systems this should return the pytz timezone for system local time. '''
+  if pytz and os.path.exists('/etc/localtime'):
+    parts         = os.readlink('/etc/localtime').split('/')[-2:]
+    if parts:
+      if parts[-1] == 'UTC':
+        return pytz.utc
+      try:
+        return pytz.timezone('/'.join(parts))
+      except:
+        pass
 
 
-### DateTimes
+TIME_UTC                = pytz and pytz.utc or None
+TIME_ZONE               = _TryToGetLocalTimeZone()
+
+
+
+### DateTime Limits
 
 # We add/subtract one day from date min/max so they can be localized without overflowing
 DATE_MIN                = datetime.date.min + datetime.timedelta(days=1)
@@ -21,16 +45,6 @@ DATETIME_MIN            = datetime.datetime.min.replace(tzinfo=TIME_UTC) + datet
 DATETIME_MAX            = datetime.datetime.max.replace(tzinfo=TIME_UTC) - datetime.timedelta(days=1)
 
 
-### Field sizes
-
-MAX_LENGTH_KEY          =  32
-MAX_LENGTH_SLUG         =  base.utils.strings.MAX_LENGTH_SLUG   #  64
-MAX_LENGTH_TITLE        =  96
-MAX_LENGTH_FILEPATH     = 255
-MAX_LENGTH_IDENTIFIER   = 255
-MAX_LENGTH_RECAPTCHA    = 740
-
-
 
 ### Quotes
 
