@@ -67,6 +67,9 @@ def AskStdInForPermission(prompt='(y/N)? ', default='N'):
 
 
 _interactive_lock     = threading.RLock()
+def _GoingInteractive(banner, namespace):
+  ''' A method that can be monkey-patched to add context to the GoInteractive() session '''
+  return banner
 
 def GoInteractive(**kwargs):
   ''' Go interactive in the console window with all globals() and locals() in scope. '''
@@ -81,17 +84,7 @@ def GoInteractive(**kwargs):
   finally:
     del frame
   banner          = '\n*** Interactive Console ***\n'
-  if base.utils.django.available:
-    from . import boot    # xyzzy -- not where this actually is...
-    from django.conf import settings
-    for appname, module in boot.boot.apps.items():
-      namespace[appname]  = module
-    namespace['Get']      = lambda x: base.identifiers.Identifier(x).Get()
-    namespace['settings'] = settings
-    banner        += '\nLocal scope includes:\n'
-    banner        += ' - all {} modules\n'.format(settings.SERVER_NAME)
-    banner        += ' - settings\n'
-    banner        += ' - Get(identifier)\n\n'
+  banner          = _GoingInteractive(banner, namespace)
   banner          += 'Terminate the session with CTRL-D.\n'
   if kwargs:
     namespace.update(kwargs)
