@@ -127,7 +127,7 @@ def CollapseWhitespace(text):
 
 def UnifyWhitespace(s, preferred=' '):
   ''' Replaces any standard whitespace character with a known type of space. '''
-  return ''.join([(c.isspace() and preferred or c) for c in text])
+  return ''.join([(c.isspace() and preferred or c) for c in s])
 
 
 def UnifyQuotes(s, preferred='"'):
