@@ -26,6 +26,11 @@ def EnsureTzInfo(dt, timezone=None):
   return dt.replace(tzinfo=timezone)
 
 
+def DateFromDateTime(timestamp):
+  ''' Shifts a timestamp to local time, then strips the time part and returns the date. '''
+  return LocalTime(timestamp).date()
+
+
 def DateTimeFromDate(date):
   ''' Promotes a date object into a datetime object by setting the time to high-noon, local time. '''
   timestamp       = datetime.datetime.combine(date, datetime.time(12, 00))
